@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: script.py 3939 2008-05-29 19:15:42Z richb $"
-__version__   = "$Revision: 3939 $"
-__date__      = "$Date: 2008-05-29 15:15:42 -0400 (Thu, 29 May 2008) $"
+__id__        = "$Id: script.py 4338 2008-11-17 22:05:37Z joanied $"
+__version__   = "$Revision: 4338 $"
+__date__      = "$Date: 2008-11-17 17:05:37 -0500 (Mon, 17 Nov 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -180,8 +180,8 @@ class Script(default.Script):
         keyBindings.add(
             keybindings.KeyBinding(
                 "n",
-                1 << settings.MODIFIER_ORCA,
-                1 << settings.MODIFIER_ORCA,
+                settings.defaultModifierMask,
+                settings.ORCA_MODIFIER_MASK,
                 self.inputEventHandlers["toggleReadMailHandler"]))
         return keyBindings
 
@@ -262,7 +262,7 @@ class Script(default.Script):
                             # Only speak the screen label if we haven't already
                             # done so.
                             #
-                            if text and not self.setupLabels.has_key(label):
+                            if text and label not in self.setupLabels:
                                 # Translators: this is the name of a setup
                                 # assistant window/screen in Evolution.
                                 #
@@ -291,7 +291,7 @@ class Script(default.Script):
             # label, then just ignore it.
             #
             text = self.getDisplayedText(label)
-            if text and not self.setupLabels.has_key(label):
+            if text and label not in self.setupLabels:
                 # Most of the Setup Assistant screens have a useful piece
                 # of text starting with the word "Please". We want to speak
                 # these. For the first screen, the useful piece of text
@@ -596,6 +596,12 @@ class Script(default.Script):
                                event,
                                debug.getAccessibleDetails(event.source))
 
+        # We always automatically go back to focus tracking mode when
+        # the focus changes.
+        #
+        if self.flatReviewContext:
+            self.toggleFlatReviewMode()
+
         # self.printAncestry(event.source)
 
         # 1) Mail view: current message pane: individual lines of text.
@@ -1327,7 +1333,8 @@ class Script(default.Script):
             # so in this case.
             #
             if obj.getRole() == pyatspi.ROLE_FRAME and \
-                obj.name.endswith(_("Assistant")):
+                (obj.name.endswith(_("Assistant")) or \
+                obj.name.startswith(_("Assistant"))):
                 debug.println(self.debugLevel,
                               "evolution.locusOfFocusChanged - " \
                               + "setup assistant.")
@@ -1398,7 +1405,8 @@ class Script(default.Script):
                 # so in this case.
                 #
                 if obj.getRole() == pyatspi.ROLE_FRAME and \
-                    obj.name.endswith(_("Assistant")):
+                    (obj.name.endswith(_("Assistant")) or \
+                    obj.name.startswith(_("Assistant"))):
                     debug.println(self.debugLevel,
                                   "evolution.onStateChanged - " \
                                   + "setup assistant.")
@@ -1413,7 +1421,7 @@ class Script(default.Script):
                     # seen this panel, then handle it.
                     #
                     elif event.source.getRole() == pyatspi.ROLE_PANEL and \
-                        not self.setupPanels.has_key(event.source):
+                        event.source not in self.setupPanels:
                         self.handleSetupAssistantPanel(event.source)
                         self.setupPanels[event.source] = True
                         break
