@@ -21,17 +21,14 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 4279 2008-10-07 22:40:23Z joanied $"
-__version__   = "$Revision: 4279 $"
-__date__      = "$Date: 2008-10-07 18:40:23 -0400 (Tue, 07 Oct 2008) $"
+__id__        = "$Id: settings.py 4384 2008-12-06 21:33:48Z joanied $"
+__version__   = "$Revision: 4384 $"
+__date__      = "$Date: 2008-12-06 16:33:48 -0500 (Sat, 06 Dec 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import os
 import re
-import shutil
-
-import platform
 
 screenWidth = 640
 screenHeight = 480
@@ -849,7 +846,7 @@ def isOrcaAutostarted():
     """
     prefix = "/desktop/gnome/applications/at/visual/"
     try:
-	return ("orca" in gconfClient.get_string(prefix + "exec")) \
+        return ("orca" in gconfClient.get_string(prefix + "exec")) \
            and gconfClient.get_bool(prefix + "startup")
     except:
         return False
@@ -1003,6 +1000,15 @@ setScriptMapping(re.compile(_('Bon Echo')), "Mozilla")
 #
 setScriptMapping(re.compile(_('Minefield')), "Mozilla")
 
+# Translators: see the regular expression note above.  This is for a
+# version of Mozilla Firefox, which chooses to create strange names
+# for itself at the drop of a hat. [[[TODO - JD: Not marked for
+# translation due to string freeze. I'm not convinced it needs to
+# be translated either.]]]
+#
+#setScriptMapping(re.compile(_('Shiretoko')), "Mozilla")
+setScriptMapping(re.compile('Shiretoko'), "Mozilla")
+
 # This is a temporary fix for the schema/FF 3.0 not being accessible
 # issue. (See GNOME bugs #535827 and #555466.)
 #
